# Agglomerative Late Fusion Algorithm (ALFA) Utilities

## Overview
This python package contains all ALFA related utilities, so that the base detectors and the ALFA detector can interact with each other.